# skill-musicassistant

Mike Gray/Oscillate Labs
[mike@oscillatelabs.net](mailto:mike@oscillatelabs.net)
Apache-2.0

An OVOS/Neon skill to control media through Music Assistant.

OCP _must_ be disabled for this skill to work.
